@@ -46,7 +46,6 @@ module.exports = {
         "crystal",
         "dart",
         "dotnet",
-        "environment",
         "executiontime",
         "exit",
         "git",
@@ -71,6 +70,7 @@ module.exports = {
         "session",
         "shell",
         "spotify",
+        "strava",
         "sysinfo",
         "terraform",
         "text",
