@@ -13,7 +13,7 @@ func (a *angular) string() string {
 	return a.language.string()
 }
 
-func (a *angular) init(props properties, env environmentInfo) {
+func (a *angular) init(props Properties, env Environment) {
 	a.language = language{
 		env:        env,
 		props:      props,
