@@ -25,6 +25,14 @@ func (p properties) getOneOfBool(property, legacyProperty Property, defaultValue
 	return p.getBool(property, defaultValue)
 }
 
+func (p properties) getOneOfString(property, legacyProperty Property, defaultValue string) string {
+	_, found := p[legacyProperty]
+	if found {
+		return p.getString(legacyProperty, defaultValue)
+	}
+	return p.getString(property, defaultValue)
+}
+
 func (p properties) hasOneOf(properties ...Property) bool {
 	for _, property := range properties {
 		if _, found := p[property]; found {
@@ -34,6 +42,10 @@ func (p properties) hasOneOf(properties ...Property) bool {
 	return false
 }
 
+func (p properties) set(property Property, value interface{}) {
+	p[property] = value
+}
+
 // GIT Segement
 
 const (
@@ -109,9 +121,9 @@ func (g *git) deprecatedString(statusColorsEnabled bool) string {
 
 func (g *git) SetStatusColor() {
 	if g.props.getBool(ColorBackground, true) {
-		g.props[BackgroundOverride] = g.getStatusColor(g.props.getColor(BackgroundOverride, ""))
+		g.props.set(BackgroundOverride, g.getStatusColor(g.props.getColor(BackgroundOverride, "")))
 	} else {
-		g.props[ForegroundOverride] = g.getStatusColor(g.props.getColor(ForegroundOverride, ""))
+		g.props.set(ForegroundOverride, g.getStatusColor(g.props.getColor(ForegroundOverride, "")))
 	}
 }
 
@@ -170,10 +182,10 @@ const (
 func (e *exit) deprecatedString() string {
 	colorBackground := e.props.getBool(ColorBackground, false)
 	if e.Code != 0 && !colorBackground {
-		e.props[ForegroundOverride] = e.props.getColor(ErrorColor, e.props.getColor(ForegroundOverride, ""))
+		e.props.set(ForegroundOverride, e.props.getColor(ErrorColor, e.props.getColor(ForegroundOverride, "")))
 	}
 	if e.Code != 0 && colorBackground {
-		e.props[BackgroundOverride] = e.props.getColor(ErrorColor, e.props.getColor(BackgroundOverride, ""))
+		e.props.set(BackgroundOverride, e.props.getColor(ErrorColor, e.props.getColor(BackgroundOverride, "")))
 	}
 	if e.Code == 0 {
 		return e.props.getString(SuccessIcon, "")
@@ -220,9 +232,9 @@ func (b *batt) colorSegment() {
 	}
 	colorBackground := b.props.getBool(ColorBackground, false)
 	if colorBackground {
-		b.props[BackgroundOverride] = b.props.getColor(colorProperty, b.props.getColor(BackgroundOverride, ""))
+		b.props.set(BackgroundOverride, b.props.getColor(colorProperty, b.props.getColor(BackgroundOverride, "")))
 	} else {
-		b.props[ForegroundOverride] = b.props.getColor(colorProperty, b.props.getColor(ForegroundOverride, ""))
+		b.props.set(ForegroundOverride, b.props.getColor(colorProperty, b.props.getColor(ForegroundOverride, "")))
 	}
 }
 
@@ -375,10 +387,10 @@ func (l *language) string() string {
 
 func (l *language) colorMismatch() {
 	if l.props.getBool(ColorBackground, false) {
-		l.props[BackgroundOverride] = l.props.getColor(VersionMismatchColor, l.props.getColor(BackgroundOverride, ""))
+		l.props.set(BackgroundOverride, l.props.getColor(VersionMismatchColor, l.props.getColor(BackgroundOverride, "")))
 		return
 	}
-	l.props[ForegroundOverride] = l.props.getColor(VersionMismatchColor, l.props.getColor(ForegroundOverride, ""))
+	l.props.set(ForegroundOverride, l.props.getColor(VersionMismatchColor, l.props.getColor(ForegroundOverride, "")))
 }
 
 // Python
@@ -405,3 +417,44 @@ const (
 	// DisplayPackageManager shows if NPM or Yarn is used
 	DisplayPackageManager Property = "display_package_manager"
 )
+
+// Environment Variable
+
+type envvar struct {
+	props Properties
+	env   Environment
+	Value string
+}
+
+const (
+	// VarName name of the variable
+	VarName Property = "var_name"
+)
+
+func (e *envvar) enabled() bool {
+	name := e.props.getString(VarName, "")
+	e.Value = e.env.getenv(name)
+	return e.Value != ""
+}
+
+func (e *envvar) string() string {
+	segmentTemplate := e.props.getString(SegmentTemplate, "")
+	if len(segmentTemplate) == 0 {
+		return e.Value
+	}
+	template := &textTemplate{
+		Template: segmentTemplate,
+		Context:  e,
+		Env:      e.env,
+	}
+	text, err := template.render()
+	if err != nil {
+		return err.Error()
+	}
+	return text
+}
+
+func (e *envvar) init(props Properties, env Environment) {
+	e.props = props
+	e.env = env
+}
