@@ -43,11 +43,11 @@ func TestIpifySegment(t *testing.T) {
 
 	for _, tc := range cases {
 		env := &MockedEnvironment{}
-		var props properties = map[Property]interface{}{
+		props := properties{
 			CacheTimeout: 0,
 		}
 
-		env.On("doGet", IPIFYAPIURL).Return([]byte(tc.Response), tc.Error)
+		env.On("HTTPRequest", IPIFYAPIURL).Return([]byte(tc.Response), tc.Error)
 
 		if tc.Template != "" {
 			props[SegmentTemplate] = tc.Template
