@@ -130,7 +130,7 @@ func TestNSSegment(t *testing.T) {
 
 	for _, tc := range cases {
 		env := &MockedEnvironment{}
-		var props properties = map[Property]interface{}{
+		props := properties{
 			CacheTimeout: tc.CacheTimeout,
 			URL:          "FAKE",
 		}
@@ -139,7 +139,7 @@ func TestNSSegment(t *testing.T) {
 		cache.On("get", FAKEAPIURL).Return(tc.JSONResponse, !tc.CacheFoundFail)
 		cache.On("set", FAKEAPIURL, tc.JSONResponse, tc.CacheTimeout).Return()
 
-		env.On("doGet", FAKEAPIURL).Return([]byte(tc.JSONResponse), tc.Error)
+		env.On("HTTPRequest", FAKEAPIURL).Return([]byte(tc.JSONResponse), tc.Error)
 		env.On("cache", nil).Return(cache)
 
 		if tc.Template != "" {
