@@ -5,8 +5,8 @@ import (
 )
 
 type osInfo struct {
-	props properties
-	env   environmentInfo
+	props Properties
+	env   Environment
 	OS    string
 }
 
@@ -145,7 +145,7 @@ func (n *osInfo) getDistroName(distro, defaultName string) string {
 	return n.props.getString(Linux, "\uF17C")
 }
 
-func (n *osInfo) init(props properties, env environmentInfo) {
+func (n *osInfo) init(props Properties, env Environment) {
 	n.props = props
 	n.env = env
 }
