@@ -7,8 +7,8 @@ import (
 )
 
 type owm struct {
-	props       properties
-	env         environmentInfo
+	props       Properties
+	env         Environment
 	Temperature float64
 	Weather     string
 	URL         string
@@ -99,7 +99,7 @@ func (d *owm) getResult() (*owmDataResponse, error) {
 	httpTimeout := d.props.getInt(HTTPTimeout, DefaultHTTPTimeout)
 	d.URL = fmt.Sprintf("http://api.openweathermap.org/data/2.5/weather?q=%s&units=%s&appid=%s", location, units, apikey)
 
-	body, err := d.env.doGet(d.URL, httpTimeout)
+	body, err := d.env.HTTPRequest(d.URL, httpTimeout)
 	if err != nil {
 		return new(owmDataResponse), err
 	}
@@ -173,7 +173,7 @@ func (d *owm) setStatus() error {
 	return nil
 }
 
-func (d *owm) init(props properties, env environmentInfo) {
+func (d *owm) init(props Properties, env Environment) {
 	d.props = props
 	d.env = env
 }
