@@ -51,14 +51,14 @@ func TestOWMSegmentSingle(t *testing.T) {
 
 	for _, tc := range cases {
 		env := &MockedEnvironment{}
-		var props properties = map[Property]interface{}{
+		props := properties{
 			APIKey:       "key",
 			Location:     "AMSTERDAM,NL",
 			Units:        "metric",
 			CacheTimeout: 0,
 		}
 
-		env.On("doGet", OWMAPIURL).Return([]byte(tc.JSONResponse), tc.Error)
+		env.On("HTTPRequest", OWMAPIURL).Return([]byte(tc.JSONResponse), tc.Error)
 
 		if tc.Template != "" {
 			props[SegmentTemplate] = tc.Template
@@ -184,10 +184,10 @@ func TestOWMSegmentIcons(t *testing.T) {
 		response := fmt.Sprintf(`{"weather":[{"icon":"%s"}],"main":{"temp":20}}`, tc.IconID)
 		expectedString := fmt.Sprintf("%s (20°C)", tc.ExpectedIconString)
 
-		env.On("doGet", OWMAPIURL).Return([]byte(response), nil)
+		env.On("HTTPRequest", OWMAPIURL).Return([]byte(response), nil)
 
 		o := &owm{
-			props: map[Property]interface{}{
+			props: properties{
 				APIKey:       "key",
 				Location:     "AMSTERDAM,NL",
 				Units:        "metric",
@@ -207,10 +207,10 @@ func TestOWMSegmentIcons(t *testing.T) {
 		response := fmt.Sprintf(`{"weather":[{"icon":"%s"}],"main":{"temp":20}}`, tc.IconID)
 		expectedString := fmt.Sprintf("[%s (20°C)](http://api.openweathermap.org/data/2.5/weather?q=AMSTERDAM,NL&units=metric&appid=key)", tc.ExpectedIconString)
 
-		env.On("doGet", OWMAPIURL).Return([]byte(response), nil)
+		env.On("HTTPRequest", OWMAPIURL).Return([]byte(response), nil)
 
 		o := &owm{
-			props: map[Property]interface{}{
+			props: properties{
 				APIKey:          "key",
 				Location:        "AMSTERDAM,NL",
 				Units:           "metric",
@@ -232,7 +232,7 @@ func TestOWMSegmentFromCache(t *testing.T) {
 	env := &MockedEnvironment{}
 	cache := &MockedCache{}
 	o := &owm{
-		props: map[Property]interface{}{
+		props: properties{
 			APIKey:   "key",
 			Location: "AMSTERDAM,NL",
 			Units:    "metric",
@@ -256,7 +256,7 @@ func TestOWMSegmentFromCacheWithHyperlink(t *testing.T) {
 	cache := &MockedCache{}
 
 	o := &owm{
-		props: map[Property]interface{}{
+		props: properties{
 			APIKey:          "key",
 			Location:        "AMSTERDAM,NL",
 			Units:           "metric",
