@@ -134,7 +134,7 @@ func (env *MockedEnvironment) getWindowsRegistryKeyValue(path string) (*windowsR
 	return args.Get(0).(*windowsRegistryValue), args.Error(1)
 }
 
-func (env *MockedEnvironment) doGet(url string, timeout int, requestModifiers ...HTTPRequestModifier) ([]byte, error) {
+func (env *MockedEnvironment) HTTPRequest(url string, timeout int, requestModifiers ...HTTPRequestModifier) ([]byte, error) {
 	args := env.Called(url)
 	return args.Get(0).([]byte), args.Error(1)
 }
@@ -198,6 +198,11 @@ func (env *MockedEnvironment) convertToLinuxPath(path string) string {
 	return args.String(0)
 }
 
+func (env *MockedEnvironment) getWifiNetwork() (*wifiInfo, error) {
+	args := env.Called(nil)
+	return args.Get(0).(*wifiInfo), args.Error(1)
+}
+
 const (
 	homeBill        = "/home/bill"
 	homeJan         = "/usr/home/jan"
@@ -262,7 +267,7 @@ func TestRootLocationHome(t *testing.T) {
 		env.On("getRuntimeGOOS", nil).Return("")
 		path := &path{
 			env: env,
-			props: map[Property]interface{}{
+			props: properties{
 				HomeIcon:            tc.HomeIcon,
 				WindowsRegistryIcon: tc.RegistryIcon,
 			},
@@ -414,7 +419,7 @@ func TestAgnosterPathStyles(t *testing.T) {
 		env.On("getArgs", nil).Return(args)
 		path := &path{
 			env: env,
-			props: map[Property]interface{}{
+			props: properties{
 				FolderSeparatorIcon: tc.FolderSeparatorIcon,
 				Style:               tc.Style,
 				MaxDepth:            tc.MaxDepth,
@@ -535,7 +540,7 @@ func TestGetFullPath(t *testing.T) {
 		if len(tc.Template) == 0 {
 			tc.Template = "{{ if gt .StackCount 0 }}{{ .StackCount }} {{ end }}{{ .Path }}"
 		}
-		var props properties = map[Property]interface{}{
+		props := properties{
 			Style:           tc.Style,
 			SegmentTemplate: tc.Template,
 		}
@@ -583,7 +588,7 @@ func TestGetFullPathCustomMappedLocations(t *testing.T) {
 		env.On("getArgs", nil).Return(args)
 		path := &path{
 			env: env,
-			props: map[Property]interface{}{
+			props: properties{
 				MappedLocationsEnabled: false,
 				MappedLocations:        tc.MappedLocations,
 			},
@@ -634,7 +639,7 @@ func TestGetFolderPathCustomMappedLocations(t *testing.T) {
 	env.On("getArgs", nil).Return(args)
 	path := &path{
 		env: env,
-		props: map[Property]interface{}{
+		props: properties{
 			MappedLocations: map[string]string{
 				"/a/b/c/d": "#",
 			},
@@ -681,7 +686,7 @@ func TestAgnosterPath(t *testing.T) { // nolint:dupl
 		env.On("getArgs", nil).Return(args)
 		path := &path{
 			env: env,
-			props: map[Property]interface{}{
+			props: properties{
 				FolderSeparatorIcon: " > ",
 				FolderIcon:          "f",
 				HomeIcon:            "~",
@@ -729,7 +734,7 @@ func TestAgnosterLeftPath(t *testing.T) { // nolint:dupl
 		env.On("getArgs", nil).Return(args)
 		path := &path{
 			env: env,
-			props: map[Property]interface{}{
+			props: properties{
 				FolderSeparatorIcon: " > ",
 				FolderIcon:          "f",
 				HomeIcon:            "~",
@@ -777,7 +782,7 @@ func TestGetPwd(t *testing.T) {
 		env.On("getArgs", nil).Return(args)
 		path := &path{
 			env: env,
-			props: map[Property]interface{}{
+			props: properties{
 				MappedLocationsEnabled: tc.MappedLocationsEnabled,
 				MappedLocations: map[string]string{
 					"/a/b/c/d": "#",
