@@ -3,8 +3,8 @@ package main
 import "strings"
 
 type session struct {
-	props properties
-	env   environmentInfo
+	props Properties
+	env   Environment
 	text  string
 
 	UserName     string
@@ -45,7 +45,7 @@ func (s *session) string() string {
 	return s.getFormattedText()
 }
 
-func (s *session) init(props properties, env environmentInfo) {
+func (s *session) init(props Properties, env Environment) {
 	s.props = props
 	s.env = env
 }
